/**
 * 交叉表数据模型，仪表盘交叉表和电子表格公用
 */
import { NumberFormat, SelectType } from './chart-config';
import { Cellset } from './standard-model';
export declare class CellMeta {
    value: string;
    raw?: string;
    dataType?: 'number' | 'string' | 'datetime' | 'date' | 'time' | 'chart';
    props: {
        guid: string;
        hidden: boolean;
    };
}
export declare class RowColumnMeta {
    total: boolean;
    subtotal: boolean;
    cells: CellMeta[];
}
/** 交叉表 olap 模型 */
export declare class OlapResponseBase<R extends RowColumnMeta, C extends RowColumnMeta> {
    rows: R[];
    columns: C[];
    values: Cellset;
}
export declare enum CrossTableColumnType {
    /** 序号列 */
    INDEX = "INDEX",
    /** 总计列 */
    TOTAL = "TOTAL",
    /** 小计列 */
    SUBTOTAL = "SUBTOTAL",
    /** '度量'列 */
    MEASURE = "MEASURE",
    /** 普通字段列 */
    NORMAL = "NORMAL",
    /** 事件填报列 */
    EVENT = "EVENT",
    /** 普通字段列 */
    TREE = "TREE",
    /** 值列 */
    VALUE = "VALUE",
    /** 行上无字段时，左侧值列 */
    LEFT_VALUE = "LEFT_VALUE",
    /** CellChart列 */
    CELL_CHART = "CELL_CHART"
}
export declare enum CrossTableRowType {
    NORMAL = "NORMAL",
    MEASURE = "MEASURE",
    /** 总计行 */
    TOTAL = "TOTAL",
    /** 小计行 */
    SUBTOTAL = "SUBTOTAL",
    /** 指标分组行 */
    MEASUREGROUP = "MEASUREGROUP",
    /** 树状的小计行位置，和 TOTAL 互斥 */
    SUBTOTALPOSITION = "SUBTOTALPOSITION"
}
export declare type CrossTableHeaderMeta = {
    [key: string]: '';
};
/** 交叉表列的视图模型 */
export declare class CrossTableColumnModel {
    /** 行维度或列度量的 uuid */
    uuid: string;
    type: CrossTableColumnType;
    /** 列维度头 */
    headerMeta?: CrossTableHeaderMeta;
    /** 度量在列上时，对应的数据下标 */
    olapValueIndex?: number;
}
export declare class CrossTableRowModel {
    /** 列维度或行度量的 uuid */
    uuid: string;
    type: Exclude<CrossTableRowType, CrossTableRowType.MEASUREGROUP | CrossTableRowType.SUBTOTALPOSITION>;
    /** 列维度头 */
    headerMeta?: CrossTableHeaderMeta;
    isHeaderLastRow?: boolean;
    /** 数据区索引 */
    rowIndex?: number;
    /** 原始值，处理空值 */
    originalData?: {
        [guid: string]: any;
    };
}
export interface CrossTableNumberFormat extends NumberFormat {
    selectType?: SelectType;
    unit?: string;
}
export declare class CrossTableFieldSetting {
    aliasName: string;
    alignment: 'left' | 'center' | 'right';
    areaType: string;
    desc: string;
    imageSize?: number;
    label: boolean;
    nameChangedFlag: boolean;
    numberFormat?: CrossTableNumberFormat;
    timeFormat?: string;
    uuid: string;
}
export declare class CrossTableTotalConfig {
    /** 展示位置 */
    displayPosition: 'top' | 'bottom' | 'left' | 'right';
    /** 固定在顶部 */
    summaryFixBottom?: boolean;
    /** 列/行总计 */
    insertSummary: boolean;
    /** 总计逻辑 */
    totalLogic: 'auto' | 'custom';
    /** 总计逻辑：自定义 */
    currentMeasure?: {
        summaryWay: {
            [pathId: string]: any;
        };
        measures?: any[];
    };
    /** 总计别名 */
    totalAlias: string;
    /** 是否显示行/列小计 */
    showSubTotal: boolean;
    /** 制定维度 */
    dimValue: string[];
    /** 列小计别名 */
    subTotalAlias: string;
    /** 小计配置 */
    subTotalConfig: {
        subTotalAlias: '';
        dimValue: any[];
        aggregate: string;
    }[];
    subTotalAliasNameMapping: {
        [uuid: string]: string[];
    };
    /** 获取小计别名 */
    static getSubTotalAlias(totalConfig: CrossTableTotalConfig, dimGuid: string, index?: number): string;
    /** 判断是否时单小计 */
    static isSingleSubTotal(totalConfig: CrossTableTotalConfig, dimGuid: string): boolean;
}
