/**
 * @author 墨辞
 * @description 自定义组件数据面板的配置接口定义
 */
import { DataPanelDataSchema, DataSchemaAreaItem, QueryAxisType, DataSchemaRule, FieldType, FieldGroupType } from './dataPanel';
/**
 * platform 环境
 */
export declare enum Platform {
    /** 仪表板 */
    dashboard = "dashboard",
    /** 电子表格 */
    excel = "excel"
}
/**
 * 区块id枚举
 * - area_column: 列id
 * - area_row: 行id
 * - drill: 下钻id
 * - filters: 过滤器id
 * */
export declare type DataSchemaAreaId = 'area_column' | 'area_row' | 'drill' | 'filters';
/**
 * 自定义组件的数据面板配置项
 */
export interface DataSchemaArea extends Pick<DataSchemaAreaItem, 'id' | 'name' | 'nameTip'> {
    /** 字段类型 */
    queryAxis: keyof typeof QueryAxisType;
    /** 规则配置 */
    rule: DataSchemaAreaRule;
}
/**
 * 自定义组件的字段规则
 */
export interface DataSchemaAreaRule extends Pick<DataSchemaRule, 'placeholder' | 'maxColNum' | 'required'> {
    /** 允许拖拽的字段类型 */
    fieldTypes?: (keyof typeof FieldType)[];
    /** 允许拖入的字段组类型 */
    fieldGroupTypes?: (keyof typeof FieldGroupType)[];
}
/**
 * 自定义组件的 data-schema
 */
export interface DataSchema {
    /** 字段设置 */
    areas: DataSchemaArea[];
    /** 结果展示 */
    resultDisplay: DataPanelDataSchema['resultDisplay'];
}
