/**
 * @author 忘悠
 * @description 数据面板存储模型
 */
import { QueryAxisType, FreshTimeUnit } from './base';
import { ColumnFieldInfo } from './dataSchemaItem';
export declare class DataConfig {
    /** 数据集 id 们 */
    sources: {
        id: string;
        name?: string;
    }[];
    /** 数据面板字段列表 */
    area: {
        id: string;
        areaName: string;
        columnList: DataConfigAreaItemColumn[];
        queryAxis: QueryAxisType;
        rule: {
            maxColNum: number;
            required: boolean;
            show: boolean;
            type: 'dimension' | 'measure' | 'all';
        };
    }[];
    /** 自动刷新设置 */
    freshTime: {
        isFreshEnable: boolean;
        freshTimeNumber: number;
        freshTimeUnit: FreshTimeUnit;
    };
    /** 图表上一次刷新时间，用于判断是否自动刷新 */
    lastRefreshTime: number;
    /** 取数条目限制  */
    limitNum: number;
    /** 是否展示全部,交叉表底部选择可以展示全部 crossTableIsSelectAll */
    crossTableIsSelectAll?: boolean;
    /** 是否明细查询，目前仅支持部分图表 */
    queryDetail: boolean;
}
export interface CommonCompInputComplexFilter {
    /** ??? */
    filters?: CommonCompInputComplexFilterItem[];
    /** 可能值：and, or */
    operator?: 'and' | 'or';
}
export declare type TimeTypeFilter = 'relative' | 'absolute';
export interface CommonCompInputComplexFilterItem {
    values?: any[];
    attributeId?: any;
    attributeName?: string;
    dimensionId?: string;
    dimensionName?: string;
    /** 2.对于维度：=(精确匹配), contain(包含), start-with(开头是), !=(不匹配), not-contain(不包含), null(为空), not-null(不为空), in(枚举单选或复选) */
    oper?: string;
    /** 判断是否是复选(可用于来做tab选择的falg) */
    multiple?: string;
    /** 按固定值排序 */
    sortByOperands?: boolean;
    /** 日期粒度类型 */
    type?: TimeTypeFilter;
    /** 区间粒度类型 */
    endType?: TimeTypeFilter;
    /** 区间粒度类型 */
    beginType?: TimeTypeFilter;
    /** 筛选项展示值，查询控件展示 */
    displayValues?: any[];
}
/** 字段详细信息
 */
export declare class DataConfigAreaItemColumn {
    id: string;
    queryAxis: QueryAxisType;
    columnList?: DataConfigAreaItemColumn[];
    /** 组合图特有，表示轴的状态 */
    chartStatus?: string;
    pathId: string;
    uuid: string;
    /** 设置的聚合方式，aggregator 表示字段默认的聚合方式，从字段来 */
    useaggregator?: string;
    /** 百分比格式 */
    percentileType?: string;
    /** 百分比值 */
    percentileValue?: number;
    /** 当前字段的皮肤 */
    skin?: string;
    /** 字段类型, 理论上和skin是同一个字段 */
    colType?: string;
    /** 同环比信息 */
    dateField?: string;
    /** 排名信息 */
    rank?: string;
    /** 高级计算值类型 */
    contrastValueType?: string;
    /** 排序信息 */
    order?: string;
    /** 自定义排序信息 */
    customType?: string;
    /** 累计计算, 同比环比 */
    contrastType?: string;
    /** 是否开启同期对比 */
    contrastWithQuery?: boolean;
    /** 是否脱敏配置 */
    isMask?: boolean;
    /** 自定义 */
    customOrder?: string[];
    /** 同环比数据对比值查询类型 */
    ratioCalcType?: string;
    /** 过滤器配置信息 */
    filter?: any;
    /** 度量情况下会存在此值 */
    complexFilter?: CommonCompInputComplexFilter;
    /** 最后一天 */
    aggArgs?: string[];
    /** 字段排序信息 */
    sortByField?: {
        field: any;
        aggregation: string;
        sortType: any;
    };
    /** 是否是字段组 */
    isFieldGroup?: boolean;
    /** 对应的fieldInfo，用于字段组回溯 */
    fieldInfo?: ColumnFieldInfo;
    granularity?: string;
}
