/**
 * @author 忘悠
 * @description 数据面板每个区域的配置信息
 */
import * as React from 'react';
import { DateGranularity, Field, FieldAttribute, FolderAndHierarchyNode } from '../cube/cube-model';
import { FieldType, QueryAxisType, FieldGroupType, SecondFieldType, ChartStatus, StackedSortType, RetainAreaId } from './base';
import { DataConfigAreaItemColumn } from './dataConfig';
export declare enum FieldConfigTypes {
    /** 聚合方式, 度量默认打开 */
    aggregation = "aggregation",
    /** 同环比, 度量默认打开 */
    contrast = "contrast",
    /** 高级计算, 度量默认打开 */
    advancedCalculation = "advancedCalculation",
    /** 数据展示格式, 默认打开 */
    numberFormat = "numberFormat",
    /** 字段别名 */
    rename = "rename",
    /** 对齐方式, 默认关闭 */
    align = "align",
    /** 排序, 默认打开 */
    sort = "sort",
    /** 时间格式 */
    timeFormat = "timeFormat",
    /** 图形样式 */
    chartType = "chartType",
    /** 图片大小 */
    imageSize = "imageSize",
    /** 字段组切换 */
    switchFieldGroup = "switchFieldGroup"
}
export declare type DropDownMenuFieldConfig = AggregationConfig | ContrastConfig | AdvancedCalculationConfig | NumberFormatConfig | LabelConfig | AlignConfig | SortConfig | FieldGroupConfig | ChartTypeConfig | ImageSizeConfig | TimeFormatConfig;
export declare type FieldConfigs = Array<DropDownMenuFieldConfig>;
export declare type ResetFieldConfigType = {
    menuInfo: DropdownMenuItem;
    field: DataConfigAreaItemColumn;
    path: (string | number)[];
    fieldInfo: FieldInfo;
    component: any;
};
export declare type ResetMenuType = {
    menuItem: DropdownMenuItem | DropdownMenuItem[];
    field: DataConfigAreaItemColumn;
    fieldInfo: FieldInfo;
    area: DataSchemaAreaItem;
    component: any;
};
interface FieldCommonConfig {
    menuConfig?: DropdownMenuItem;
    /** 默认是否展示，部分配置不需要默认打开，作为选配项即可 */
    visible?: boolean;
    /** 是否禁用 */
    disabled?: boolean;
    /** 支持的字段类型 */
    usefulFieldtype?: FieldType[];
    /** 是否在底部有分割线 */
    hasDivider?: boolean;
    /** 当前配置项，可使用的选项  */
    usefulValues?: any[];
    /** 禁用配置项，此项会对配置项开启disabled */
    disabledValues?: string[];
    /** 下拉菜单的类型值，固定写死，不需要覆盖 */
    dropdownMenuType?: keyof typeof DropDownMenuType;
    /**
     * 图表自定义渲染处理函数，图表可以在这里对渲染菜单进行自定义
     * @param item 当前菜单的配置信息, 聚合方式时会传递回配置数组
     * @param field 当前字段配置
     * @param component 组件信息
     */
    resetMenu?: (params: ResetMenuType) => DropdownMenuItem | DropdownMenuItem[];
    /**
     * 图表自定义处理
     * @param menuInfo 当前点击的菜单信息
     * @param field 当前字段配置信息
     * @param path 当前字段配置信息在图表area中的路径信息
     * @param fieldInfo 当前数据集中的字段信息
     * @param component 当前组件信息
     * @return component 返回更新后的组件信息
     */
    resetFieldConfig?: (params: ResetFieldConfigType) => any;
}
export declare enum Aggregators {
    sum = "sum",
    avg = "avg",
    count = "count",
    countd = "countd",
    null = "null",
    more = "more",
    max = "max",
    min = "min",
    median = "median",
    percentile = "percentile",
    stddev_pop = "stddev_pop",
    stddev_samp = "stddev_samp",
    var_pop = "var_pop",
    var_samp = "var_samp",
    last_period = "last_period"
}
/** 聚合方式, 度量默认打开 */
export interface AggregationConfig extends FieldCommonConfig {
    type: FieldConfigTypes.aggregation;
    /** 聚合方式 ，可以自定义排序 */
    usefulValue?: Aggregators[];
    /** 更多聚合方式 ，可以自定义排序 */
    moreAggregators?: Aggregators[];
    /** 不展示的聚合方式 */
    hideValues?: Aggregators[];
    /** 展示但禁用的聚合方式 */
    disbaledAggregators?: Aggregators[];
    /** 配置的当前聚合方式 */
    value?: Aggregators;
}
export declare enum ContrastTypes {
    customContrast = "customContrast",
    noneContrast = "noneContrast"
}
/** 同环比, 度量默认打开 */
export interface ContrastConfig extends FieldCommonConfig {
    type: FieldConfigTypes.contrast;
    /** 同环比类型，可以自定义排序  */
    usefulValue?: ContrastTypes[];
    /** 不展示的同环比方式  */
    hideValues?: ContrastTypes[];
}
export declare enum AdvanceCalTypes {
    increase = "increase",
    percentRatio = "percentRatio",
    rank = "rank",
    none = "none"
}
export declare enum AdvanceCalcDateTypes {
    day = "day",
    week = "week",
    month = "month",
    quarter = "quarter",
    year = "year"
}
/** 高级计算, 度量默认打开 */
export interface AdvancedCalculationConfig extends FieldCommonConfig {
    type: FieldConfigTypes.advancedCalculation;
    /** 高级计算类型，支持排序 */
    usefulValue?: AdvanceCalTypes[];
    /** 隐藏的类型 */
    hideValues?: AdvanceCalTypes[];
    /** 展示但禁用的类型 */
    disabledAdvanceCalTypes?: AdvanceCalTypes[];
    /** 高级计算时间字段类型 */
    dateType?: AdvanceCalcDateTypes;
}
export declare enum NumberFormats {
    auto = "auto",
    int = "int",
    oneDecimal = "oneDecimal",
    twoDecimal = "twoDecimal",
    percent = "percent",
    oneDecimalPercent = "oneDecimalPercent",
    twoDecimalPercent = "twoDecimalPercent",
    custom = "custom"
}
/** 数据展示格式, 默认打开 */
export interface NumberFormatConfig extends FieldCommonConfig {
    type: FieldConfigTypes.numberFormat;
    /** 高级计算类型，支持排序 */
    usefulValue?: NumberFormats[];
    usePrefix?: boolean;
    value?: NumberFormats;
    /** 关闭手动输入 */
    hideManualInput?: boolean;
    /** 关闭数量量级使用标识位 */
    hideDataMagnitude?: boolean;
}
/** 字段别名 */
export interface LabelConfig extends FieldCommonConfig {
    type: FieldConfigTypes.rename;
    useDescription?: boolean;
}
export declare enum AlignTypes {
    auto = "auto",
    left = "left",
    center = "center",
    right = "right"
}
/** 对齐方式, 默认关闭 */
export interface AlignConfig extends FieldCommonConfig {
    type: FieldConfigTypes.align;
    value?: AlignTypes;
    hideValues?: string[];
}
export declare enum SortTypes {
    none = "",
    asc = "ASC",
    desc = "DESC",
    custom = "custom",
    group_asc = "GROUP_ASC",
    group_desc = "GROUP_DESC",
    field = "field",
    advance_sort = "advance_sort"
}
/** 排序, 默认打开 */
export interface SortConfig extends FieldCommonConfig {
    type: FieldConfigTypes.sort;
    useAdvancedSort?: boolean;
    value?: SortTypes;
    hideValues?: SortTypes[];
    sortTypes?: SortTypes[];
    /** 高级排序是否支持从数据面板选择度量的快捷选项 */
    presetSelectEnabled?: boolean;
}
/** 字段组内字段切换 */
export interface FieldGroupConfig extends FieldCommonConfig {
    type: FieldConfigTypes.switchFieldGroup;
}
export declare enum FieldChartTypes {
    bar = "bar",
    line = "line",
    polyline = "polyline"
}
/** 图形样式 */
export interface ChartTypeConfig extends FieldCommonConfig {
    type: FieldConfigTypes.chartType;
    value?: FieldChartTypes;
}
export declare enum ImageSizes {
    small = "small",
    medium = "medium",
    big = "big",
    custom = "custom"
}
/** 图片大小 */
export interface ImageSizeConfig extends FieldCommonConfig {
    type: FieldConfigTypes.imageSize;
    value?: ImageSizes;
}
export interface TimeFormatConfig extends FieldCommonConfig {
    type: FieldConfigTypes.timeFormat;
    value?: string;
    granularity?: DateGranularity;
}
/**
 * 每个下拉菜单的选项
 */
export declare class DropdownMenuItem {
    /** 当前配置项类型，如聚合，展示格式 */
    type: string;
    /** 唯一表示，不用value是因为需要和之前的逻辑保持兼容 */
    id?: string;
    title?: string;
    icon?: React.ReactNode;
    children?: {
        [key in string]: DropdownMenuItem;
    };
    hasDivider?: boolean;
    /** 是否禁用 */
    disabled?: boolean;
    /** 是否隐藏 */
    isHidden?: boolean;
    selected?: boolean;
    /** 操作icon列表 */
    operatoredIcons?: any[];
    /** 当前选中值 */
    value?: string;
    /** 额外的配置项，个别图表用到 */
    extra?: {
        /** 使用组内排序 */
        hasGroupSort?: boolean;
        /** 交叉表等禁用全局排序 */
        disabledGlobalSort?: boolean;
    };
}
/** 过滤器 | 更多 | 删除 | 隐藏 | 钻取 |  钻取并联动 | 自定义 */
export declare enum OperationTypes {
    MORE = "more",
    DRILL = "drill",
    FILTER = "filter",
    DELETE = "delete",
    HIDE = "hide",
    CUSTOM = "custom"
}
export interface FieldRuntime {
    /** 是否是下钻根节点 */
    isDrillRoot?: boolean;
    fieldGroup?: any;
    /** 在原数组中的序号 */
    index?: number;
    /** 下钻组是否折叠 */
    isFold?: boolean;
}
/** 字段组内具体字段的字段信息，包含是否隐藏等+columnList信息 */
export interface ChildFieldInfo {
    /** 是否隐藏 */
    isHidden: boolean;
    /** 是否被选择过 */
    hasSelected: boolean;
    /** key，即attributeId */
    key: string;
    /** 其他Field信息(columnList) */
    [key: string]: any;
}
/** 字段组的fieldInfo信息 */
export interface FieldGroupInfo {
    fieldGroup: FolderAndHierarchyNode;
    defaultFieldId: string;
    children: {
        [key: string]: ChildFieldInfo;
    };
}
/** fieldinfo只能保存来自数据集的信息，通过uuid和component中的字段对应 */
export interface FieldInfo {
    field: Field;
    attribute: FieldAttribute;
    uuid: string;
    /** 字段运行时信息 */
    runtime?: FieldRuntime;
    /** 字段组field信息 */
    fieldGroup?: FieldGroupInfo;
}
export interface ColumnFieldInfo {
    uniqueId: string;
    uuid: string;
    fieldGroup: {
        fieldGroupId: string;
        defaultFieldId: string;
        children: {
            [key: string]: ChildFieldInfo;
        };
    };
}
export interface VirtualFieldInfo {
    name: string;
    icon?: React.ReactNode;
}
export interface AreaMapItem {
    fields: FieldInfo[];
    id: RetainAreaId | string;
    drillGroupCount?: number;
    /** 允许和哪个area进行字段交换，值为areaId */
    allowExchangeWith?: string;
    componentId: string;
    allowDimensionRepeat?: boolean;
    cubeQueryTime: string;
}
export declare type AreaMap = {
    [key: string]: AreaMapItem;
};
/** 字段的下拉菜单配置，保存在ref中，防止ping'fan */
export interface FieldMenuConfig {
    menu?: DropdownMenuItem[];
    fieldInfo?: FieldInfo;
    areaId?: string;
    fieldConfig?: CompFieldConfig;
    aliasDesc?: {
        fieldName: string;
        aliasName: string;
        desc?: string;
    };
    /** 是否是指标树节点 */
    isNode?: boolean;
    nodeInfo?: {
        uuid: string;
        name: string;
    };
    hasChildren?: boolean;
    expanded?: boolean;
}
export declare type ChangeFieldMenuConfigs = (c?: FieldMenuConfig | ((c: FieldMenuConfig[]) => FieldMenuConfig[])) => FieldMenuConfig[];
export interface CompFieldConfig {
    field: any;
    path: (string | number)[];
}
export declare class OperationMenuItem {
    type: OperationTypes;
    /** hover提示文字 */
    title?: string;
    icon?: React.ReactNode;
    disabled?: boolean;
    /** 是否展示 */
    visible?: boolean | ((component: any, fieldInfo: FieldInfo) => boolean);
    action?: (fieldInfo: FieldInfo, area: DataSchemaAreaItem, e: React.MouseEvent) => any;
}
export declare class DataSchemaRule {
    /** 默认展示值 */
    placeholder?: string;
    /** 字段配置个数限制
     */
    maxColNum?: number | ((areaMap: AreaMap, isConvertQueryInput?: boolean) => number);
    /** 是否取数必须 */
    required?: boolean;
    /** 允许拖拽的字段类型 */
    fieldTypes?: FieldType[];
    /** 允许拖入的字段组类型 */
    fieldGroupTypes?: FieldGroupType[];
    /** 细粒度字段类型 */
    secondFieldTypes?: SecondFieldType[];
    /** 是否不允许双击自动添加字段 */
    disableDblAddField?: boolean;
    /** 字段数量为0是否隐藏 */
    isHiddenWhenNoField?: boolean;
    /** 是否可以配置多个下钻组  一般图表只支持一个，而交叉表最多支持三个 */
    drillGroupCount?: number;
    /** 允许和其后的area调换位置 */
    allowExchangeWithNext?: boolean;
    /** 允许维度与其他area重复校验 */
    allowDimensionRepeat?: boolean;
}
export declare class DataSchemaAreaItem {
    /** area id */
    id: RetainAreaId | string;
    /** area 名称 */
    name: string;
    /** 名称右边的提示icon内容 */
    nameTip?: React.ReactNode;
    /** 组合图特有，表示轴的状态 */
    chartStatus?: ChartStatus;
    /** 堆积柱图/条形图特有，表示排序类型 */
    stackedSortType?: StackedSortType;
    /** 是否支持多度量和颜色图例并存 */
    isMultiMeasureWithColorLegend?: boolean;
    /** 是否可以批量设置 */
    allowBatchConfig?: boolean | ((areaMap: AreaMap) => boolean);
    /** 字段类型 */
    queryAxis?: QueryAxisType;
    /** 规则配置 */
    rule?: DataSchemaRule;
    hooks?: {
        /** 字段拖入之后的处理 */
        afterDrag?: (nextFields: FieldInfo[], areaMap: AreaMap, from: string, to: string) => FieldInfo[];
        /** 拖放的时候的回调，校验失败返回报错信息 */
        onDrop?: (areaMap: AreaMap) => {
            /** 字段是否允许放置 */
            isValid: boolean;
            /** 需要弹出的msg */
            msg?: Message;
        };
        /** 同步字段到component的之前的钩子 */
        beforeSyncFieldsToComponent?: (component: any, areaMap: AreaMap) => {
            component: any;
        };
        /** 生成虚拟字段方法 */
        getVirtualFields?: (areaMap: AreaMap, component: any) => VirtualFieldInfo[];
    };
    /** 字段配置项信息 */
    fieldConfigs?: FieldConfigs;
    /** 支持的icon菜单列表 */
    operationList?: OperationMenuItem[];
    /** area dom 插槽，主要用来自定义一些图表的特殊配置组件，目前只实现了
     * 底部插槽，后续有需要再接
     */
    slot?: Partial<{
        /** 顶部插槽 */
        top: () => React.ReactNode;
        /** 底部插槽 */
        bottom: (component: any, freshComponent: OnFreshComponentType) => React.ReactNode;
        /** 左边插槽 */
        left: () => React.ReactNode;
        /** 右边插槽 */
        right: () => React.ReactNode;
    }>;
}
export declare type OnFreshComponentType = (comp: any, changeAttributeList?: string[], isFresh?: boolean) => any;
export interface Message {
    type: 'success' | 'warn' | 'info' | 'error';
    text: string;
}
export declare const DropDownMenuType: {
    /** 排序 */
    order: string;
    /** 聚合方式 */
    aggregater: string;
    /** 高级计算 */
    calculation: string;
    /** 同环比 */
    ratio: string;
    /** 数值格式化 */
    numberFormat: string;
    /** 对齐方式 */
    alignment: string;
    /** 图片尺寸 */
    imageSize: string;
    /** 时间格式化 */
    timeFormat: string;
    /** 组合图展示格式 */
    chartType: string;
    /** 重命名 */
    renameSetting: string;
    /** 百分比 */
    percentile: string;
    /** 字段排序 */
    fieldOrder: string;
    /** 最后时间点，这里因为id为字段的pathId，所以不适用聚合方式类型，避免无法区分问题 */
    lastPeriod: string;
    /** 字段组替换 */
    switchFieldGroup: string;
    /** 指标管理默认展开配置 */
    defaultExpand: string;
};
export {};
