/**
 * @author 海狸
 * @description 自定义菜单 props 接口
 */
/// <reference types="react" />
import { ComponentProps } from './component-props';
import { ChartType, ComponentType } from './component-type';
/**
 * 自定义菜单的页面信息
 */
export interface MenuPageConfig {
    /** 页面工作空间 id */
    workspaceId: string;
    /** 页面 id */
    id: string;
    /** 页面模式, 编辑态/预览态 */
    mode: 'preview' | 'edit';
    /** 当前设备 */
    device: 'pc' | 'mobile';
}
/**
 * 自定义菜单 props 接口
 */
export interface MenuComponentProps {
    /** 页面信息 */
    pageConfig: MenuPageConfig;
    /** 操作 */
    dispatch?: MenuComponentPropsDispatch;
    /** 自定义菜单展示模式 */
    menuMode?: CustomMenuMode;
}
/** 自定义菜单弹窗参数 */
export interface MenuModalFuncProps {
    /** PC端弹窗宽度 */
    width?: string | number;
    /** PC端和移动端点击取消按钮时的回调 */
    onCancel?: (...args: any[]) => any;
    /** 内容 */
    content?: React.ReactNode;
    /** 标题 */
    title?: string;
    /** PC端点击确定回调，返回 promise 可以延迟关闭。 */
    onOk?: (...args: any[]) => any;
    /** PC端确认按钮文字 */
    okText?: React.ReactNode;
    /** PC端取消按钮文字 */
    cancelText?: React.ReactNode;
    /** PC端确认按钮属性 */
    okButtonProps?: {
        style?: React.CSSProperties;
        disabled?: boolean | undefined;
    };
    /** PC端取消按属性 */
    cancelButtonProps?: {
        style?: React.CSSProperties;
        disabled?: boolean | undefined;
    };
}
/**
 * 唤起弹窗
 */
interface ComponentPropsActionOpenModal {
    type: 'openModal';
    payload: MenuModalFuncProps;
}
/**
 * 手动关闭弹窗
 */
interface ComponentPropsActionCloseModal {
    type: 'closeModal';
    payload: {};
}
export declare type MenuComponentPropsDispatch = (param: ComponentPropsActionOpenModal | ComponentPropsActionCloseModal) => void;
/**
 * 自定义图表卡片菜单 props 接口
 */
export interface MenuComponentChartProps extends MenuComponentProps {
    /** 卡片菜单 */
    chart: MenuChart;
}
/**
 * 仪表板图表自定义菜单接口
 */
export interface MenuChart extends ComponentProps {
    /** 图表类型 */
    componentType: ComponentType;
    /** 自定义组件类型, 当组件是自定义组件时传入  */
    customComponentType?: ChartType;
}
/**
 * 电子表格自定义菜单
 */
export interface MenuComponentExcelProps extends MenuComponentProps {
    sheets: MenuSheet[];
}
export interface MenuSheet {
    /** 标签 id */
    sheetId: string;
    /** 标签名称 */
    sheetName: string;
    /** 标签顺序 */
    sheetOrder: number;
}
/**
 * 自定义菜单展示模式
 */
export declare enum CustomMenuMode {
    /**
     * 平铺,直接展示在界面上
     */
    tile = 1,
    /**
     * 收起,隐藏至 更多下拉框 中
     */
    pack = 2
}
export {};
