/**
 * @author 凌亦
 * @description 图表统一输入模型
 */
/**
 * -------------------------------------------------------------------------------------------
 * | areas区域模型
 * -------------------------------------------------------------------------------------------
 */
/** 字段信息 */
export interface FieldModel {
    /** 唯一Id */
    fieldId: string;
    /** qbi中对应pathId */
    pathId?: string;
    /** 字段名 */
    fieldName: string;
    /** 最终展示别名 */
    showName: string;
    /** 是否计算字段 */
    isCalc?: boolean;
    /** 是否显示字段 */
    isHidden?: boolean;
    /** 如：calc */
    skin?: string;
    /** 值的类型 */
    valueType?: FieldValueType;
    /** 字段类型: 维度或度量 */
    fieldType: FieldCommonType;
    /** 聚合方式 */
    aggregation?: FieldAggregation | string;
    /** [QBI特有] 数据渲染形式，目前有imageUrl用于交叉表、排行榜图片渲染 */
    displayType?: 'imageUrl' | '';
    /** [QBI特有] 数据集格式化配置，如#,##0.00% */
    rawFormat?: string;
    /** [QBI特有] 数据集维度类型, TimeRegionInBackend, 需迁移，防止循环依赖 */
    dimGranularity?: any;
    /** [FBI特有] 日期格式 */
    dateFormat?: string;
    /** 最终格式化配置（注：qbi目前是放在styleConfig中，该字段并未被使用） */
    /** ！！首先得产品层面统一 */
    format?: QbiFormatModel | FbiFormatModel;
    /** 排序 */
    order?: FieldOrder;
    /** 自定义排序 */
    customOrder?: string[];
    /** [FBI特有] 排序优先级（大的排前面） */
    orderPriority?: number;
    /** 高级计算：同环比等 */
    advancedCalculation?: 'year-to-year' | 'month-to-year';
    /** 当前图表的过滤条件集合 */
    complexFilter: {
        limitNum: number;
        filter: any;
    };
    uuid: string;
    /** 字段排名信息 */
    rank?: string;
    /** 累计计算日期类型 */
    granularity?: string;
    /** [FBI特有] 时间类型 */
    dateStep?: 'year' | 'year-financial' | 'quarter' | 'month' | 'week-last7' | 'week' | 'week-monday' | 'week-tuesday' | 'week-wednesday' | 'week-thursday' | 'week-friday' | 'week-saturday' | 'day' | 'hour' | 'minute' | 'second';
    /** 不同图表字段特殊扩展信息 */
    extends?: FieldModelExtends;
    fdow?: number;
    timeFormat?: string;
    refCustomRegion?: string;
}
/** 通用字段聚合方式 */
export declare type FieldAggregation = 'sum' | 'avg' | 'max' | 'min' | 'count' | 'countd';
/** 通用字段类型（维度/度量） */
export declare type FieldCommonType = 'dimension' | 'measure';
/** 通用字段值类型 */
export declare type FieldValueType = 'number' | 'string' | 'date' | 'datetime' | 'geographic' | 'calc' | 'unknown';
/** 通用字段排序 */
export declare type FieldOrder = 'asc' | 'desc' | 'custom' | null;
/** 不同图表字段特殊扩展信息 */
export declare type FieldModelExtends = any;
/** 区域信息，例如：区分x值轴、y值轴、颜色、细分、尺寸等等，qbi、fbi 要统一映射 */
export declare type AreaType = 'row' | 'column' | 'xAxis' | 'yMainAxis' | 'ySecondaryAxis' | 'color' | 'legend' | 'size' | 'drill' | 'filters' | 'dimValues' | 'area_measure' | 'time';
export interface AreaModel {
    /** 区域类型 */
    areaType: AreaType;
    /** 区域名称 */
    areaName?: string;
    /** 字段信息 */
    fields: FieldModel[];
    /** 各图表的扩展信息 */
    extends?: AreaModelExtends;
}
export declare type AreaModelExtends = any;
/** QBI format模型 */
export interface QbiFormatModel {
    fmt: string;
    fmtType: 'CN' | 'KMG' | 'CNT' | 'Custom' | 'None';
    decimalPlaces: number;
    thousandth: boolean;
    showPercent: boolean;
}
/** fbi format */
export declare type FbiFormatModel = any;
/**
 * -------------------------------------------------------------------------------------------
 * | 数据集合
 * | NOTE: Cellset中不含头部
 * -------------------------------------------------------------------------------------------
 */
/** 单元格数据值 */
export interface DataCell {
    /** 所属字段id（一般是度量） */
    fieldId: string;
    /** 原始值 */
    originValue: string;
    /** 展示值 */
    value: string;
    geoInfo?: object;
    /** 敏感字段 */
    dataMask?: boolean;
    props?: {
        dataMask?: boolean;
    };
}
/** 数据值集合 */
export declare type Cellset = DataCell[][];
export interface RowColumnHeaderCell extends DataCell {
    /** fbi中代表数据集建模后的字段类型, qbi中需要梳理？ */
    dataType?: string;
    latitude?: string;
    longitude?: string;
    props?: {
        fid: string;
        guid: string;
        type: string;
        aggregator?: string;
        granularity?: string;
        label: string;
        description?: string;
        format: string;
        dataMask?: boolean;
    };
}
export interface RowColumnHeader {
    /** 是否为总计行或列 */
    total: boolean;
    /** 是否为小计行或列 */
    subtotal: boolean;
    /** 行或列内单元（注：列头下是按一列一列来组织的） */
    cells: RowColumnHeaderCell[];
}
/**
 * -------------------------------------------------------------------------------------------
 * | 最终输入模型
 * -------------------------------------------------------------------------------------------
 */
export declare type ChartInputModel<S = StyleConfigModel> = {
    /** 区域及字段信息 */
    areas: AreaModel[];
    /** 配置信息 */
    styleConfig: S;
    /** 数据集高级配置 */
    advancedConfig?: AdvancedConfigModel;
    /** 数值区域的数据 */
    rows: Cellset;
    /** 保留全部rows，只看排除交互式分析操作会对rows进行筛选，图表内部仍需要全部rows */
    originRows?: Cellset;
    /** 全局配置 */
    globalConfig?: GlobalConfig;
    /** 行头数据（仅轴查询（交叉表）下有此值） */
    rowHeaders?: RowColumnHeader[];
    /** 列头数据（非轴查询下，此数据可能与areas中的数据相同） */
    columnHeaders?: RowColumnHeader[];
} & S;
/** 图表样式配置 */
export interface StyleConfigModel {
    [key: string]: any;
}
/** 数据集高级配置 */
export interface AdvancedConfigModel {
    [key: string]: any;
    /** 合并单元格 */
    mergeCell?: boolean;
    /** 跨区域维度对齐配置 */
    alignmentConfig?: DimensionAlignmentItem[];
}
/** 跨区块对齐信息 */
export interface DimensionAlignmentItem {
    id: string;
    /** 当前区块维度 */
    currentFieldId: string;
    /** 当前数据集id */
    currentBindId: string;
    /** 关联区块 */
    colIndex: number;
    /** 关联区块维度 */
    correlationFieldId: string;
    /** 关联数据集id */
    correlationBindId: string;
}
export declare enum Env {
    /** 电子表格 */
    excel = "excel",
    /** pc */
    pc = "pc",
    /** 移动 */
    mobile = "mobile"
}
/** 高级分析对应的返回结果 */
interface AdvancedResultItem {
    /** 异常值检测返回的结果 */
    anomalyDetectionResults?: any[];
    /** 预测返回的结果 */
    forecastResults?: any[];
    /** 辅助线返回的结果 */
    summarizeResults?: any[];
    /** 趋势线返回的结果 */
    trendLineResults?: any[];
    /** 聚类返回结果 */
    clusteringResults?: any[];
    /** 词云图频次/分词结果 */
    wordCloudResult?: {
        /** 维度fieldId */
        dimFieldId?: string;
        /** 度量fieldId, 频次就为undefined */
        measureFieldId?: string;
        /** 具体词云数据 */
        data?: any[];
    };
}
export interface DataCompareResultItem {
    /** 数据对比支持的日期粒度枚举类型 */
    type: string;
    /** 对比周期对应的数据集 */
    cellset?: any[][];
    /** 对比周期对应的高级分析结果 */
    advancedResult?: AdvancedResultItem;
    /** 对比结果对应的新的数据模型 */
    rows?: Cellset;
}
/** 图表全局配置 */
export interface GlobalConfig {
    /** 高级分析结果 */
    advancedResult?: AdvancedResultItem;
    /** 数据对比结果 */
    dataCompareResult?: DataCompareResultItem[];
    /** 指标计算方式 */
    indicatorCalculation: 'latest' | 'summary';
    /** 阶段汇总数据结果 */
    totalResult?: {
        rows?: Cellset;
    };
    /** 标注计算结果 */
    annotationResult?: any;
    /** 是否钻取 */
    isDrill?: boolean;
    /** 被钻取的维度 */
    originDrillDimPathId?: string;
    /** 图表接收的卡片上交互式分析的信息, 栈结构保留了历史操作记录 */
    chartSelectParams?: any;
    /** 图表接收到卡片通过右上角菜单进入标注模式 */
    annotationParam: {
        isEnter: boolean;
    };
    /** 当前被钻取到的维度 */
    currentDrillDimPathId?: string;
    /** 联动维度 */
    relationDim?: string;
    /** 环境 */
    env?: Env[];
}
/** CrossTableCell图的最终输入配置 */
export interface CellChartInputModel<S = StyleConfigModel> {
    /** 区域及字段信息 */
    areas: AreaModel[];
    /** mini图对应的数据 */
    rows: Cellset;
    /** mini图的样式配置 */
    styleConfig: S;
}
export {};
