"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault.js");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ParamDataType = exports.FilterAttr = exports.Aggregator = exports.RegionGranularity = exports.DateGranularity = exports.SecondDataType = exports.DataType = exports.JoinCondition = exports.TableRelation = exports.TableJoinType = exports.CubeModel = exports.SchemaExtraInfo = exports.CubeSchema = exports.PhysicalSchema = void 0;

var _classCallCheck2 = _interopRequireDefault(require("@babel/runtime/helpers/classCallCheck.js"));

var PhysicalSchema = function PhysicalSchema() {
  (0, _classCallCheck2.default)(this, PhysicalSchema);
  this.tables = [];
  this.virtualTables = [];
  this.links = [];
  this.sqlHintTypes = [];
};

exports.PhysicalSchema = PhysicalSchema;

var CubeSchema = function CubeSchema() {
  (0, _classCallCheck2.default)(this, CubeSchema);
  this.uniqueId = '';
  this.cubeId = '';
  this.datasourceId = '';
  this.caption = '';
  this.fields = [];
  this.fieldTree = [];
  this.filter = null;
  this.params = [];
  this.sqlPlaceholders = [];
};

exports.CubeSchema = CubeSchema;

var SchemaExtraInfo = function SchemaExtraInfo() {
  (0, _classCallCheck2.default)(this, SchemaExtraInfo);
  this.aimDirId = null;
  this.hasAuthorizedUse = void 0;
  this.permissionList = void 0;
  this.dataLevelAttributeIds = [];
  this.withoutColumnLevelPermissionFields = [];
  this.aggFunctions = [];
  this.isDataMaskOpen = void 0;
  this.isOpenColumnLevelPermission = void 0;
  this.isOpenRowLevelPermission = void 0;
  this.hasShadowCube = void 0;
  this.dsCreateOrigin = void 0;
};

exports.SchemaExtraInfo = SchemaExtraInfo;

var CubeModel = function CubeModel() {
  (0, _classCallCheck2.default)(this, CubeModel);
  this.physicalSchema = new PhysicalSchema();
  this.cubeSchema = new CubeSchema();
  this.metaModelVersion = '2.0';
  this.schemaExtraInfo = new SchemaExtraInfo();
};

exports.CubeModel = CubeModel;
var TableJoinType;
exports.TableJoinType = TableJoinType;

(function (TableJoinType) {
  TableJoinType["LEFT_OUTER_JOIN"] = "LEFT_OUTER_JOIN";
  TableJoinType["INNER_JOIN"] = "INNER_JOIN";
  TableJoinType["FULL_OUTER_JOIN"] = "FULL_OUTER_JOIN";
  TableJoinType["JOIN_ERROR"] = "JOIN_ERROR";
})(TableJoinType || (exports.TableJoinType = TableJoinType = {}));

var TableRelation;
exports.TableRelation = TableRelation;

(function (TableRelation) {
  TableRelation["MANY_TO_ONE"] = "many-to-one";
})(TableRelation || (exports.TableRelation = TableRelation = {}));

var JoinCondition;
exports.JoinCondition = JoinCondition;

(function (JoinCondition) {
  JoinCondition["EQUAL_TO"] = "equal-to";
  JoinCondition["UNEQUAL_TO"] = "unequal-to";
  JoinCondition["GREATER_THAN"] = "greater-than";
  JoinCondition["LESS_THAN"] = "less-than";
})(JoinCondition || (exports.JoinCondition = JoinCondition = {}));

var DataType;
exports.DataType = DataType;

(function (DataType) {
  DataType["number"] = "number";
  DataType["string"] = "string";
  DataType["date"] = "date";
  DataType["datetime"] = "datetime";
  DataType["time"] = "time";
})(DataType || (exports.DataType = DataType = {}));

var SecondDataType;
exports.SecondDataType = SecondDataType;

(function (SecondDataType) {
  SecondDataType["number"] = "number";
  SecondDataType["string"] = "string";
  SecondDataType["geographic"] = "geographic";
  SecondDataType["imageUrl"] = "imageUrl";
  SecondDataType["date"] = "date";
  SecondDataType["datetime"] = "datetime";
  SecondDataType["time"] = "time";
})(SecondDataType || (exports.SecondDataType = SecondDataType = {}));

var DateGranularity;
exports.DateGranularity = DateGranularity;

(function (DateGranularity) {
  DateGranularity["year"] = "year";
  DateGranularity["quarter"] = "year-quarter";
  DateGranularity["month"] = "year-month";
  DateGranularity["week"] = "year-week";
  DateGranularity["day"] = "year-month-day";
  DateGranularity["hour"] = "hour";
  DateGranularity["minute"] = "hour-minute";
  DateGranularity["second"] = "hour-minute-second";
  DateGranularity["datetime"] = "datetime";
})(DateGranularity || (exports.DateGranularity = DateGranularity = {}));

var RegionGranularity;
exports.RegionGranularity = RegionGranularity;

(function (RegionGranularity) {
  RegionGranularity["continent"] = "CONTINENT";
  RegionGranularity["country"] = "COUNTRY";
  RegionGranularity["region"] = "REGION";
  RegionGranularity["custom_region"] = "CUSTOM_REGION";
  RegionGranularity["province"] = "PROVINCE";
  RegionGranularity["city"] = "CITY";
  RegionGranularity["xian"] = "XIAN";
  RegionGranularity["lng"] = "LNG";
  RegionGranularity["lat"] = "LAT";
})(RegionGranularity || (exports.RegionGranularity = RegionGranularity = {}));

var Aggregator;
exports.Aggregator = Aggregator;

(function (Aggregator) {
  Aggregator["sum"] = "sum";
  Aggregator["count"] = "count";
  Aggregator["distinct-count"] = "distinct-count";
  Aggregator["max"] = "max";
  Aggregator["min"] = "min";
  Aggregator["avg"] = "avg";
})(Aggregator || (exports.Aggregator = Aggregator = {}));

var FilterAttr = function FilterAttr() {
  (0, _classCallCheck2.default)(this, FilterAttr);
  this.logicalOperator = void 0;
  this.filterElements = [];
  this.filters = [];
};

exports.FilterAttr = FilterAttr;
var ParamDataType;
exports.ParamDataType = ParamDataType;

(function (ParamDataType) {
  ParamDataType["string"] = "string";
  ParamDataType["number"] = "number";
  ParamDataType["dateRegion"] = "dateRegion";
  ParamDataType["monthRegion"] = "monthRegion";
  ParamDataType["weekRegion"] = "weekRegion";
  ParamDataType["yearRegion"] = "yearRegion";
  ParamDataType["ymdHmsRegion"] = "ymdHmsRegion";
})(ParamDataType || (exports.ParamDataType = ParamDataType = {}));